@@ -1,9 +1,9 @@
 """
-Quandl's API for Python.
-
-Currently supports getting, searching, and pushing datasets.
-
-"""
+    Quandl's API for Python.
+    
+    Currently supports getting, searching, and pushing datasets.
+    
+    """
 from __future__ import (print_function, division, absolute_import,
                         unicode_literals)
 import pickle
@@ -30,40 +30,63 @@ QUANDL_API_URL = 'http://www.quandl.com/api/v1/'
 
 def get(dataset, **kwargs):
     """Return dataframe of requested dataset from Quandl.
-
-    :param str dataset: Dataset codes are available on the Quandl website
-    :param str authtoken: Downloads are limited to 10 unless token is specified
-    :param str trim_start, trim_end: Optional datefilers, otherwise entire
-           dataset is returned
-    :param str collapse: Options are daily, weekly, monthly, quarterly, annual
-    :param str transformation: options are diff, rdiff, cumul, and normalize
-    :param int rows: Number of rows which will be returned
-    :param str sort_order: options are asc, desc. Default: `asc`
-    :param str returns: specify what format you wish your dataset returned as,
+        
+        :param dataset: str or list depending on single dataset or multiset usage. Dataset codes are available on the Quandl website
+        :param str authtoken: Downloads are limited to 10 unless token is specified
+        :param str trim_start, trim_end: Optional datefilers, otherwise entire
+        dataset is returned
+        :param str collapse: Options are daily, weekly, monthly, quarterly, annual
+        :param str transformation: options are diff, rdiff, cumul, and normalize
+        :param int rows: Number of rows which will be returned
+        :param str sort_order: options are asc, desc. Default: `asc`
+        :param str returns: specify what format you wish your dataset returned as,
         either `numpy` for a numpy ndarray or `pandas`. Default: `pandas`
-    :returns: :class:`pandas.DataFrame` or :class:`numpy.ndarray`
-
-    Note that Pandas expects timeseries data to be sorted ascending for most
-    timeseries functionality to work.
-
-    Any other `kwargs` passed to `get` are sent as field/value params to Quandl
-    with no interference.
-
-    """
+        :returns: :class:`pandas.DataFrame` or :class:`numpy.ndarray`
+        
+        Note that Pandas expects timeseries data to be sorted ascending for most
+        timeseries functionality to work.
+        
+        Any other `kwargs` passed to `get` are sent as field/value params to Quandl
+        with no interference.
+        
+        """
     kwargs.setdefault('sort_order', 'asc')
-
+    
     auth_token = _getauthtoken(kwargs.pop('authtoken', ''))
     trim_start = _parse_dates(kwargs.pop('trim_start', None))
     trim_end = _parse_dates(kwargs.pop('trim_end', None))
     returns = kwargs.get('returns', 'pandas')
-
-    url = QUANDL_API_URL + 'datasets/{}.csv?'.format(dataset)
+    
+    #Check whether dataset is given as a string (for a single dataset) or an array (for a multiset call)
+    
+    
+    #Unicode String
+    if type(dataset) == unicode:
+        url = QUANDL_API_URL + 'datasets/{}.csv?'.format(dataset)
+    
+    #Array
+    elif type(dataset) == list:
+        url = QUANDL_API_URL + 'multisets.csv?columns='
+        #Format for multisets call
+        dataset = [d.replace('/', '.') for d in dataset]
+        for i in dataset:
+            url += i + ','
+        #remove trailing ,
+        url = url[:-1] + '&'
+    
+    #If wrong format
+    else:
+        error = "Your dataset must either be specified as a string or an array for using multisets"
+        raise Exception(error)
+    
+    #Append all paramteres to API call
     url = _append_query_fields(url,
                                auth_token=auth_token,
                                trim_start=trim_start,
                                trim_end=trim_end,
                                **kwargs)
-
+    
+    #Determine format data is retrieved in
     if returns == 'numpy':
         try:
             u = urlopen(url)
@@ -83,37 +106,39 @@ def get(dataset, **kwargs):
 
 def push(data, code, name, authtoken='', desc='', override=False):
     """Upload a pandas Dataframe to Quandl and returns link to the dataset.
-
-    :param data: (required), pandas ts or numpy array
-    :param str code: (required), Dataset code
-                 must consist of only capital letters, numbers, and underscores
-    :param str name: (required), Dataset name
-    :param str authtoken: (required), to upload data
-    :param str desc: (optional), Description of dataset
-    :param bool overide: (optional), whether to overide dataset of same code
-    :returns: :str: link to uploaded dataset
-
-    """
+        
+        :param data: (required), pandas ts or numpy array
+        :param str code: (required), Dataset code
+        must consist of only capital letters, numbers, and underscores
+        :param str name: (required), Dataset name
+        :param str authtoken: (required), to upload data
+        :param str desc: (optional), Description of dataset
+        :param bool overide: (optional), whether to overide dataset of same code
+        :returns: :str: link to uploaded dataset
+        
+        """
     override = str(override).lower()
     token = _getauthtoken(authtoken)
     if token == '':
         error = ("You need an API token to upload your data to Quandl, "
                  "please see www.quandl.com/API for more information.")
         raise Exception(error)
-
+    #test that code is in acceptable format
     _pushcodetest(code)
     datestr = ''
-
+    
     # Verify and format the data for upload.
     if not isinstance(data, pd.core.frame.DataFrame):
         error = "only pandas data series are accepted for upload at this time"
         raise ValueError(error)
-
+    
     # check if indexed by date
     data_interm = data.to_records()
     index = data_interm.dtype.names
     datestr += ','.join(index) + '\n'
-
+    
+    
+    #format data for uploading
     for i in data_interm:
         if isinstance(i[0], datetime.datetime):
             datestr += i[0].date().isoformat()
@@ -131,10 +156,10 @@ def push(data, code, name, authtoken='', desc='', override=False):
         datestr += '\n'
 
     params = {'name': name,
-              'code': code,
-              'description': desc,
-              'update_or_create': override,
-              'data': datestr}
+        'code': code,
+        'description': desc,
+        'update_or_create': override,
+        'data': datestr}
 
     url = QUANDL_API_URL + 'datasets.json?auth_token=' + token
     jsonreturn = _htmlpush(url, params)
@@ -147,19 +172,20 @@ def push(data, code, name, authtoken='', desc='', override=False):
 
     rtn = ('http://www.quandl.com/' + jsonreturn['source_code'] + '/' +
            jsonreturn['code'])
+    #Return URL of uploaded dataset
     return rtn
 
 
 def search(query, source = None, page= 1 , authtoken = None, prints = True):
     """Return array of dictionaries of search results.
-
-    :param str query: (required), query to search with
-    :param str source: (optional), source to search
-    :param +'ve int: (optional), page number of search 
-    :param str authotoken: (optional) Quandl auth token for extended API access
-    :returns: :array: search results
-
-    """
+        
+        :param str query: (required), query to search with
+        :param str source: (optional), source to search
+        :param +'ve int: (optional), page number of search
+        :param str authotoken: (optional) Quandl auth token for extended API access
+        :returns: :array: search results
+        
+        """
     
     token = _getauthtoken(authtoken)
     search_url = 'http://www.quandl.com/api/v1/datasets.json?query='
@@ -173,7 +199,7 @@ def search(query, source = None, page= 1 , authtoken = None, prints = True):
     #Add search source if given
     if source:
         url += '&source_code=' + source
-    #Page to be searched 
+    #Page to be searched
     url += '&page=' + str(page)
     text= urlopen(url).read()
     data = json.loads(text)
@@ -199,7 +225,8 @@ def search(query, source = None, page= 1 , authtoken = None, prints = True):
             print('\n\n')
     return datalist
 
-# returns None is date is None
+
+# returns None if date is None
 def _parse_dates(date):
     if date is None:
         return date
@@ -228,7 +255,6 @@ def _htmlpush(url, raw_params):
 
 
 def _pushcodetest(code):
-    import re
     regex = re.compile('[^0-9A-Z_]')
     if regex.search(code):
         error = ("Your Quandl Code for uploaded data must consist of only "
